@@ -4,17 +4,7 @@ import abc
 import csv
 import json
 from dataclasses import dataclass, field
-from typing import (
-    Any,
-    Callable,
-    Dict,
-    Generator,
-    Iterable,
-    List,
-    Literal,
-    Optional,
-    Tuple,
-)
+from typing import Any, Callable, Dict, Generator, Iterable, List, Literal, Optional
 from urllib.parse import urlencode
 
 import jinja2
@@ -55,6 +45,7 @@ from fastapi.responses import ORJSONResponse
 from starlette.datastructures import QueryParams
 from starlette.requests import Request
 from starlette.responses import HTMLResponse, Response, StreamingResponse
+from starlette.routing import compile_path, replace_params
 from starlette.templating import Jinja2Templates, _TemplateResponse
 
 tms_settings = TMSSettings()
@@ -236,7 +227,15 @@ class EndpointsFactory(metaclass=abc.ABCMeta):
 
         base_url = str(request.base_url)
         if self.router_prefix:
-            base_url += self.router_prefix.lstrip("/")
+            prefix = self.router_prefix.lstrip("/")
+            # If we have prefix with custom path param we check and replace them with
+            # the path params provided
+            if "{" in prefix:
+                _, path_format, param_convertors = compile_path(prefix)
+                prefix, _ = replace_params(
+                    path_format, param_convertors, request.path_params.copy()
+                )
+            base_url += prefix
 
         return str(url_path.make_absolute_url(base_url=base_url))
 
@@ -756,12 +755,6 @@ class OGCFeaturesFactory(EndpointsFactory):
             bbox_filter: Annotated[Optional[List[float]], Depends(bbox_query)],
             datetime_filter: Annotated[Optional[List[str]], Depends(datetime_query)],
             properties: Annotated[Optional[List[str]], Depends(properties_query)],
-            properties_filter: Annotated[
-                List[Tuple[str, str]], Depends(properties_filter_query)
-            ],
-            function_parameters: Annotated[
-                Dict[str, str], Depends(function_parameters_query)
-            ],
             cql_filter: Annotated[Optional[AstType], Depends(filter_query)],
             sortby: Annotated[Optional[str], Depends(sortby_query)],
             geom_column: Annotated[
@@ -782,7 +775,7 @@ class OGCFeaturesFactory(EndpointsFactory):
                 int,
                 Query(
                     ge=0,
-                    lt=features_settings.max_features_per_query,
+                    le=features_settings.max_features_per_query,
                     description="Limits the number of features in the response.",
                 ),
             ] = features_settings.default_features_limit,
@@ -824,8 +817,8 @@ class OGCFeaturesFactory(EndpointsFactory):
                 ids_filter=ids_filter,
                 bbox_filter=bbox_filter,
                 datetime_filter=datetime_filter,
-                properties_filter=properties_filter,
-                function_parameters=function_parameters,
+                properties_filter=properties_filter_query(request, collection),
+                function_parameters=function_parameters_query(request, collection),
                 cql_filter=cql_filter,
                 sortby=sortby,
                 properties=properties,
@@ -1061,7 +1054,6 @@ class OGCFeaturesFactory(EndpointsFactory):
                 ),
             ] = None,
             properties: Optional[List[str]] = Depends(properties_query),
-            function_parameters: Dict[str, str] = Depends(function_parameters_query),
             output_type: Annotated[
                 Optional[MediaType], Depends(ItemsOutputType)
             ] = None,
@@ -1082,7 +1074,7 @@ class OGCFeaturesFactory(EndpointsFactory):
                 simplify=simplify,
                 ids_filter=[itemId],
                 properties=properties,
-                function_parameters=function_parameters,
+                function_parameters=function_parameters_query(request, collection),
                 geom=geom_column,
                 dt=datetime_column,
                 geom_as_wkt=geom_as_wkt,
@@ -1571,12 +1563,6 @@ class OGCTilesFactory(EndpointsFactory):
             request: Request,
             collection: Annotated[Collection, Depends(self.collection_dependency)],
             tile: Annotated[Tile, Depends(TileParams)],
-            properties_filter: Annotated[
-                List[Tuple[str, str]], Depends(properties_filter_query)
-            ],
-            function_parameters: Annotated[
-                Dict[str, str], Depends(function_parameters_query)
-            ],
             tileMatrixSetId: Annotated[
                 Literal[tuple(self.supported_tms.list())],
                 f"Identifier selecting one of the TileMatrixSetId supported (default: '{tms_settings.default_tms}')",
@@ -1622,8 +1608,8 @@ class OGCTilesFactory(EndpointsFactory):
                 ids_filter=ids_filter,
                 bbox_filter=bbox_filter,
                 datetime_filter=datetime_filter,
-                properties_filter=properties_filter,
-                function_parameters=function_parameters,
+                properties_filter=properties_filter_query(request, collection),
+                function_parameters=function_parameters_query(request, collection),
                 cql_filter=cql_filter,
                 sortby=sortby,
                 properties=properties,
@@ -1961,6 +1947,7 @@ class Endpoints(EndpointsFactory):
     def register_routes(self):
         """Register factory Routes."""
         self.ogc_features = OGCFeaturesFactory(
+            catalog_dependency=self.catalog_dependency,
             collection_dependency=self.collection_dependency,
             router_prefix=self.router_prefix,
             templates=self.templates,
@@ -1970,6 +1957,7 @@ class Endpoints(EndpointsFactory):
         self.router.include_router(self.ogc_features.router, tags=["OGC Features API"])
 
         self.ogc_tiles = OGCTilesFactory(
+            catalog_dependency=self.catalog_dependency,
             collection_dependency=self.collection_dependency,
             router_prefix=self.router_prefix,
             templates=self.templates,
